==> pipewire-docs-1%3A0.3.52-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Components", "index.html#autotoc_md0", null ],
    [ "API Documentation", "index.html#autotoc_md1", null ],
    [ "More Documentation", "index.html#autotoc_md2", null ],
    [ "Resources", "index.html#autotoc_md3", null ],
    [ "Overview", "page_overview.html", [
      [ "Motivation", "page_overview.html#autotoc_md4", null ]
    ] ],
    [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Globals", "globals.html", [
      [ "All", "globals.html", "globals_dup" ],
      [ "Functions", "globals_func.html", "globals_func" ],
      [ "Variables", "globals_vars.html", null ],
      [ "Typedefs", "globals_type.html", null ],
      [ "Enumerations", "globals_enum.html", null ],
      [ "Enumerator", "globals_eval.html", "globals_eval" ],
      [ "Macros", "globals_defs.html", "globals_defs" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"globals_defs_p.html",
"globals_k.html",
"group__pw__context.html#gad466760a74623341ac33d267581ddf39",
"group__pw__impl__link.html#ga67ddececedcfc23e682f0b860fcde648",
"group__pw__link.html#gab53c62332a757ed234d5eb91a54a23ac",
"group__pw__port.html#gac8fe785592185f71666d2d03903cc367",
"group__pw__session__manager.html#gaa50cf4a5a59e55e6a003e21cc6376996",
"group__spa__ansi.html#ga9691e3321fd9a291860a04b0d219d52f",
"group__spa__device.html#gac59665317b0bc49197df89771abf6499",
"group__spa__log.html#ga2cb43866ec2798103989dcafd611f28f",
"group__spa__node.html#gae06e2ee893ca6c894411795b564161c6",
"group__spa__param.html#gae3beebbcde434be3e21cbdb46edb92fc",
"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a830f30b6852ec554b690e5a8323a14b2",
"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaf34c622412de4a1ec7637231f2eb560b",
"group__spa__pod.html#ga7820560083401bab79329a6b3b138c7d",
"group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf",
"page_midi.html#autotoc_md28",
"structpw__client__session__methods.html#a54ba399f450c8ee5b85cfba7ad4b352a",
"structpw__impl__port__events.html#a73104e5c2b8f887977945a597fa6b1ee",
"structpw__stream__events.html#aab4b9831ef563920b401b1f9daf93042",
"structspa__io__buffers.html",
"structspa__pod__choice__body.html#a24335975777563cb1c8be5df46ed8aca"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> pipewire-docs-1%3A0.3.55-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Components", "index.html#autotoc_md0", null ],
    [ "API Documentation", "index.html#autotoc_md1", null ],
    [ "More Documentation", "index.html#autotoc_md2", null ],
    [ "Resources", "index.html#autotoc_md3", null ],
    [ "Overview", "page_overview.html", [
      [ "Motivation", "page_overview.html#autotoc_md4", null ]
    ] ],
    [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Globals", "globals.html", [
      [ "All", "globals.html", "globals_dup" ],
      [ "Functions", "globals_func.html", "globals_func" ],
      [ "Variables", "globals_vars.html", null ],
      [ "Typedefs", "globals_type.html", null ],
      [ "Enumerations", "globals_enum.html", null ],
      [ "Enumerator", "globals_eval.html", "globals_eval" ],
      [ "Macros", "globals_defs.html", "globals_defs" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"globals_defs_p.html",
"globals_k.html",
"group__pw__context.html#gad466760a74623341ac33d267581ddf39",
"group__pw__impl__link.html#ga67ddececedcfc23e682f0b860fcde648",
"group__pw__link.html#gaafb6d5e113016baef0cf9a8cc9405c31",
"group__pw__port.html#gac556c0b1548946709e9e99daa8b52b1b",
"group__pw__session__manager.html#gaa402cd6473e92b77d7f66d42dba6720f",
"group__spa__ansi.html#ga8dcc1e4283933e216eca2305dda3ccf6",
"group__spa__device.html#gab7ccc98f93f0269396bcbcd3efd1fdb8",
"group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1",
"group__spa__node.html#gade24550dee986c4a1279bfbaadce1636",
"group__spa__param.html#gae226fa3f944c8881bc74fd88a7c3aa0e",
"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a7621ee5060a7fc7cfa4d4899c183b11b",
"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaf00cc9cdd2a272c2a99b653be8dce45c",
"group__spa__pod.html#ga77978a8da43cf2f3bc74c086b046ceb0",
"group__spa__types.html#ga4fabe70032a577729bfaa7e1cb231ac6",
"page_midi.html#autotoc_md26",
"structpw__client__session__events.html#a6005c505de498fbaaaed2dd87918773f",
"structpw__impl__port.html",
"structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02",
"structspa__interface.html",
"structspa__pod__bytes.html#acf53b79878e4a426d95574190055b5e8"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
